@@ -3,11 +3,11 @@
 
 /*!
   \file
-  \brief 数学関数の補助ファイル
+  \brief w֐̕⏕t@C
 
   \author Satofumi KAMIMURA
 
-  $Id: MathUtils.h 1402 2009-10-11 12:45:16Z satofumi $
+  $Id: MathUtils.h 1545 2009-11-22 10:03:00Z satofumi $
 */
 
 #include "DetectOS.h"
@@ -17,8 +17,8 @@
 #include <math.h>
 
 #ifndef M_PI
-// Visual C++ 6.0 用
-#define M_PI 3.14159265358979323846 //!< 円周率
+// Visual C++ 6.0 p
+#define M_PI 3.14159265358979323846 //!< ~
 #endif
 
 #if defined(MSC)
