@@ -3,7 +3,7 @@
 
 /*!
   \file
-  \brief 待機
+  \brief ҋ@
 
   \author Satofumi KAMIMURA
 
@@ -13,9 +13,9 @@
 namespace qrk
 {
   /*!
-    \brief 待機
+    \brief ҋ@
 
-    \param[in] delay 待機時間 [msec]
+    \param[in] delay ҋ@ [msec]
   */
   extern void delay(int msec);
 }
