@@ -1,33 +1,34 @@
-#ifndef QRK_FINED_FILES_H
-#define QRK_FINED_FILES_H
+#ifndef QRK_FIND_FILES_H
+#define QRK_FIND_FILES_H
 
 /*!
   \file
-  \brief ディレクトリ以下のファイル探索を行う
+  \brief fBNgȉ̃t@CTs
 
   \author Satofumi KAMIMURA
 
-  $Id: findFiles.h 783 2009-05-05 08:56:26Z satofumi $
+  $Id: findFiles.h 1663 2010-02-01 07:17:58Z satofumi $
 */
 
 #include <boost/xpressive/xpressive.hpp>
 #include <vector>
+#include <string>
 
 
 namespace qrk
 {
   /*!
-    ディレクトリ以下のファイル探索を行う
+    fBNgȉ̃t@CTs
 
-    \param[out] files 見付かったファイル
-    \param[in] root_path 探索のルートディレクトリ
-    \param[in] pattern ファイルの検索パターン
+    \param[out] files tt@C
+    \param[in] root_path T̃[gfBNg
+    \param[in] pattern t@Čp^[
 
-    \return 見付かったファイル数
+    \return tt@C
   */
   extern size_t findFiles(std::vector<std::string>& files,
                           const char* root_path,
                           const boost::xpressive::sregex pattern);
 }
 
-#endif /* !QRK_FINED_FILES_H */
+#endif /* !QRK_FIND_FILES_H */
