@@ -1,13 +1,13 @@
 /*!
   \example get_timestamp.c
 
-  \brief タイムスタンプの取得サンプル
+  \brief Sample to get timestamp
 
-  TM0, TM1, TM2 コマンドを用いて、タイムスタンプを取得する
+  Get timestamp using TMO, TM1, TM2 command
 
   \author Satofumi KAMIMURA
 
-  $Id: get_timestamp.c 1194 2009-07-31 13:45:24Z satofumi $
+  $Id: get_timestamp.c 1683 2010-02-10 10:28:05Z satofumi $
 */
 
 #include "urg_ctrl.h"
@@ -27,28 +27,31 @@ static void urg_exit(urg_t *urg, const char *message)
 }
 
 
-//! main
+/*! main */
 int main(int argc, char *argv[])
 {
   enum {
     CaptureTimes = 10,
   };
 
-  const char device[] = "COM3"; /* Windows での例 */
-  //const char device[] = "/dev/ttyACM0"; /* Linux での例 */
+#ifdef WINDOWS_OS
+  const char device[] = "COM3"; /* For Windows */
+#else
+  const char device[] = "/dev/ttyACM0"; /* For Linux */
+#endif
 
   long timestamp = 0;
   int ret = 0;
   int i;
 
-  /* 接続 */
+  /* Connection */
   urg_t urg;
   ret = urg_connect(&urg, device, 115200);
   if (ret < 0) {
     urg_exit(&urg, "urg_connect()");
   }
 
-  /* タイムスタンプモードに遷移し、タイムスタンプを表示する */
+  /* Transit to timestamp mode and displays time stamp */
   urg_enableTimestampMode(&urg);
   for (i = 0; i < CaptureTimes; ++i) {
     timestamp = urg_currentTimestamp(&urg);
