@@ -1,15 +1,16 @@
 /*!
   \example captureIntensitySample.cpp
 
-  \brief 強度データの取得サンプル
+  \brief Sample to get intensity data
 
   \author Satofumi KAMIMURA
 
-  $Id: captureIntensitySample.cpp 1474 2009-11-01 05:33:08Z satofumi $
+  $Id: captureIntensitySample.cpp 1684 2010-02-10 23:56:38Z satofumi $
 */
 
 #include "UrgCtrl.h"
 #include "delay.h"
+#include <SDL.h>
 #include <cstdlib>
 #include <cstdio>
 
@@ -17,11 +18,14 @@ using namespace qrk;
 using namespace std;
 
 
-//! main
 int main(int argc, char *argv[])
 {
+  // Change the port name appropriately
+#ifdef WINDOWS_OS
   const char device[] = "COM3";
-  //const char device[] = "/dev/ttyACM0";
+#else
+  const char device[] = "/dev/ttyACM0";
+#endif
 
   UrgCtrl urg;
   if (! urg.connect(device)) {
@@ -38,21 +42,20 @@ int main(int argc, char *argv[])
   vector<long> data;
   vector<long> intensity_data;
 
+  long previous_timestamp = 0;
   for (int i = 0; i < CaptureTimes; ++i) {
     long timestamp = 0;
-
-    // 強度付きデータの取得
     int data_n = urg.captureWithIntensity(data, intensity_data, &timestamp);
-
     if (data_n > 0) {
       int front_index = urg.rad2index(0.0);
-
-      // 表示
-      // urg_minDistance() 以下の距離データは、無効値を表す
-      printf("%d: %ld [mm] (%ld), %ld [msec]\n",
-             i, data[front_index], intensity_data[front_index], timestamp);
+      printf("%d: %ld [mm] (%ld), %ld [msec] (%ld)\n",
+             i, data[front_index], intensity_data[front_index], timestamp,
+             timestamp - previous_timestamp);
+      previous_timestamp = timestamp;
+    } else {
+      --i;
+      delay(scan_msec);
     }
-    delay(scan_msec);
   }
 
 #ifdef MSC
