@@ -1,11 +1,11 @@
 /*!
   \example findUrgPortsSample.cpp
 
-  \brief FindUrgPorts の動作サンプル
+  \brief Sample of FindUrgPorts()
 
   \author Satofumi KAMIMURA
 
-  $Id: findUrgPortsSample.cpp 1474 2009-11-01 05:33:08Z satofumi $
+  $Id: findUrgPortsSample.cpp 1683 2010-02-10 10:28:05Z satofumi $
 */
 
 #include "findUrgPorts.h"
@@ -21,7 +21,7 @@ int main(int argc, char *argv[])
   vector<string> ports;
   findUrgPorts(ports);
 
-  // 見付かったポートを全て出力する
+  // Display all found ports
   printf("ports: %u\n", ports.size());
   for (vector<string>::iterator it = ports.begin();
        it != ports.end(); ++it) {
