@@ -1,11 +1,11 @@
 /*!
   \example gdCaptureSample.cpp
 
-  \brief GD コマンドによるデータ取得サンプル
+  \brief Sample to get data using GD command
 
   \author Satofumi KAMIMURA
 
-  $Id: gdCaptureSample.cpp 1474 2009-11-01 05:33:08Z satofumi $
+  $Id: gdCaptureSample.cpp 1683 2010-02-10 10:28:05Z satofumi $
 */
 
 #include "UrgCtrl.h"
@@ -19,8 +19,11 @@ using namespace std;
 //! main
 int main(int argc, char *argv[])
 {
+#ifdef WINDOWS_OS
   const char device[] = "COM3";
-  //const char device[] = "/dev/ttyACM0";
+#else
+  const char device[] = "/dev/ttyACM0";
+#endif
 
   UrgCtrl urg;
   if (! urg.connect(device)) {
@@ -28,19 +31,21 @@ int main(int argc, char *argv[])
     exit(1);
   }
 
-  // GD コマンドで指定された回数だけスキャンを行い、出力する
+  // Scans for the number of times specified as in GD command and outputs
+  // the data.
   enum { CaptureTimes = 1 };
   for (int i = 0; i < CaptureTimes; ++i) {
     long timestamp = 0;
     vector<long> data;
 
-    // 取得
+    // Get the data
     int n = urg.capture(data, &timestamp);
 
-    // 出力
+    // Display
     printf("timestamp: %ld\n", timestamp);
     for (int j = 0; j < n; ++j) {
-      // urg_minDistance() 以下の距離データは、無効値を表す
+      // The distance data that are less than urg_minDistance() are shown as
+      // invalide values
       printf("%d:%ld, ", j, data[j]);
     }
     printf("\n");
