@@ -1,11 +1,11 @@
 /*!
   \example viewPpSample.cpp
 
-  \brief PP データ内容の表示
+  \brief Displays PP data
 
   \author Satofumi KAMIMURA
 
-  $Id: viewPpSample.cpp 1474 2009-11-01 05:33:08Z satofumi $
+  $Id: viewPpSample.cpp 1683 2010-02-10 10:28:05Z satofumi $
 */
 
 #include "UrgCtrl.h"
@@ -19,8 +19,11 @@ using namespace qrk;
 //! main
 int main(int argc, char *argv[])
 {
+#ifdef WINDOWS_OS
   const char device[] = "COM3";
-  //const char device[] = "/dev/ttyACM0";
+#else
+  const char device[] = "/dev/ttyACM0";
+#endif
 
   UrgCtrl urg;
   if (! urg.connect(device)) {
@@ -28,7 +31,7 @@ int main(int argc, char *argv[])
     exit(1);
   }
 
-  // パラメータ情報の出力
+  // Display parameter information
   RangeSensorParameter parameters = urg.parameter();
   printf("model: %s\n", parameters.model.c_str());
   printf("distance_min: %ld\n", parameters.distance_min);
