@@ -1,11 +1,11 @@
 /*!
   \example viewSerialIdSample.cpp
 
-  \brief シリアル ID の取得サンプル
+  \brief Displays serial ID of URG
 
   \author Satofumi KAMIMURA
 
-  $Id: viewSerialIdSample.cpp 1474 2009-11-01 05:33:08Z satofumi $
+  $Id: viewSerialIdSample.cpp 1683 2010-02-10 10:28:05Z satofumi $
 */
 
 #include "UrgCtrl.h"
@@ -18,8 +18,11 @@ using namespace qrk;
 //! main
 int main(int argc, char *argv[])
 {
+#ifdef WINDOWS_OS
   const char device[] = "COM3";
-  //const char device[] = "/dev/ttyACM0";
+#else
+  const char device[] = "/dev/ttyACM0";
+#endif
 
   UrgCtrl urg;
   if (! urg.connect(device)) {
