@@ -1,11 +1,11 @@
 /*!
   \example viewVvSample.cpp
 
-  \brief VV データ内容の表示
+  \brief Displays VV command data
 
   \author Satofumi KAMIMURA
 
-  $Id: viewVvSample.cpp 1474 2009-11-01 05:33:08Z satofumi $
+  $Id: viewVvSample.cpp 1683 2010-02-10 10:28:05Z satofumi $
 */
 
 #include "UrgCtrl.h"
@@ -20,8 +20,11 @@ using namespace std;
 //! main
 int main(int argc, char *argv[])
 {
+#ifdef WINDOWS_OS
   const char device[] = "COM3";
-  //const char device[] = "/dev/ttyACM0";
+#else
+  const char device[] = "/dev/ttyACM0";
+#endif
 
   UrgCtrl urg;
   if (! urg.connect(device)) {
@@ -31,14 +34,14 @@ int main(int argc, char *argv[])
 
   vector<string> lines;
 
-  // バージョン情報の取得
+  // Receive version information
   urg.versionLines(lines);
   if (lines.empty()) {
     cerr << "UrgCtrl::versionLines: " << urg.what() << endl;
     exit(1);
   }
 
-  // 出力
+  // Display
   for (vector<string>::iterator it = lines.begin();
        it != lines.end(); ++it) {
     cout << *it << endl;
