@@ -1,11 +1,11 @@
 /*!
   \example scip_20_ii.cpp
 
-  \brief II 応答の取得
+  \brief Get response of II command
 
   \author Satofumi KAMIMURA
 
-  $Id: scip_20_ii.cpp 1099 2009-06-30 02:47:18Z satofumi $
+  $Id: scip_20_ii.cpp 1701 2010-02-16 05:33:25Z satofumi $
 */
 
 #include "SerialDevice.h"
@@ -19,7 +19,7 @@ using namespace qrk;
 //! main
 int main(int argc, char *argv[]) {
 
-  // 適切にポート名を変更すること
+  // Change the port name appropriately
 #if defined(WINDOWS_OS)
   const char device[] = "COM3";
 #elif defined(LINUX_OS)
@@ -31,18 +31,22 @@ int main(int argc, char *argv[]) {
   SerialDevice con;
   if (! con.connect(device, 19200)) {
     printf("SerialDevice::connect: %s\n", con.what());
+#if defined(WINDOWS_OS)
+    printf("Hit return key.\n");
+    getchar();
+#endif
     exit(1);
   }
 
-  // SCIP2.0 の呼び出しと、応答の無視
+  // Call Scip2.0 and neglect the response.
   enum { Timeout = 200 };
   con.send("SCIP2.0\n", 8);
   skip(&con, Timeout);
 
-  // "II" コマンドの発行
+  // Send "II" command
   con.send("II\n", 3);
 
-  // 受信データの表示
+  // Display the received data
   enum { LineMax = 64 + 1 };
   char buffer[LineMax];
   int n;
@@ -50,5 +54,10 @@ int main(int argc, char *argv[]) {
     printf("%s\n", buffer);
   }
 
+#if defined(WINDOWS_OS)
+  printf("Hit return key.\n");
+  getchar();
+#endif
+
   return 0;
 }
