@@ -1,6 +1,6 @@
 /*!
   \file
-  \brief 待機関数
+  \brief ҋ@֐
 
   \author Satofumi KAMIMURA
 
@@ -40,7 +40,7 @@ void delay(int msec)
   Sleep(msec);
 
 #else
-  // !!! Mac で動作しないようならば、調整する
+  // !!! Mac œ삵Ȃ悤Ȃ΁A
   usleep(1000 * msec);
 #endif
 }
