@@ -3,7 +3,7 @@
 
 /*!
   \file
-  \brief 通信ソケット管理
+  \brief ʐM\PbgǗ
 
   \author Satofumi KAMIMURA
 
@@ -19,45 +19,45 @@ namespace qrk
 
 
   /*!
-    \brief 通信ソケット管理
+    \brief ʐM\PbgǗ
   */
   class SocketSet
   {
   public:
     /*!
-      \brief コンストラクタ
+      \brief RXgN^
 
-      \param size [i] 初期状態でのソケット許容数
+      \param size [i] Ԃł̃\Pbge
     */
     explicit SocketSet(size_t size = 1);
     ~SocketSet(void);
 
 
     /*!
-      \brief ソケットの登録
+      \brief \Pbg̓o^
 
-      \param socket [i] 登録するソケット
+      \param socket [i] o^\Pbg
 
-      \retval true 登録に成功
-      \retval false 登録に失敗
+      \retval true o^ɐ
+      \retval false o^Ɏs
     */
     bool add(TCPsocket socket);
 
 
     /*!
-      \brief ソケットの削除
+      \brief \Pbg̍폜
 
-      \param socket [i] 削除するソケット
+      \param socket [i] 폜\Pbg
     */
     void del(TCPsocket socket);
 
 
     /*!
-      \brief 受信データがあるかの確認
+      \brief Mf[^邩̊mF
 
-      \param timeout [i] タイムアウト時間 [msec]
+      \param timeout [i] ^CAEg [msec]
 
-      \return 受信データのあるソケット数
+      \return Mf[^̂\Pbg
     */
     size_t check(int timeout);
 
