@@ -3,7 +3,7 @@
 
 /*!
   \file
-  \brief TCP/IP サーバ
+  \brief TCP/IP T[o
 
   \author Satofumi KAMIMURA
 
@@ -16,7 +16,7 @@
 
 namespace qrk
 {
-  //! TCP/IP サーバ
+  //! TCP/IP T[o
   class TcpipServer : public Connection
   {
   public:
