@@ -3,7 +3,7 @@
 
 /*!
   \file
-  \brief 角度の型管理
+  \brief px̌^Ǘ
 
   \author Satofumi KAMIMURA
 
@@ -14,7 +14,7 @@
 namespace qrk
 {
   /*!
-    \brief 角度の型管理
+    \brief px̌^Ǘ
   */
   class Angle
   {
@@ -35,17 +35,17 @@ namespace qrk
 
 
     /*!
-      \brief degree 角度への変換
+      \brief degree pxւ̕ϊ
 
-      \return degree 角度
+      \return degree px
     */
     int to_deg(void) const;
 
 
     /*!
-      \brief radian 角度への変換
+      \brief radian pxւ̕ϊ
 
-      \return radian 角度
+      \return radian px
     */
     double to_rad(void) const;
 
@@ -58,19 +58,19 @@ namespace qrk
 
 
   /*!
-    \brief radian 角度を Angle に変換
+    \brief radian px Angle ɕϊ
 
-    \param[in] radian radian 角度
-    \return Angle オブジェクト
+    \param[in] radian radian px
+    \return Angle IuWFNg
   */
   extern Angle rad(double radian);
 
 
   /*!
-    \brief degree 角度を Angle に変換
+    \brief degree px Angle ɕϊ
 
-    \param[in] degree degree 角度
-    \return Angle オブジェクト
+    \param[in] degree degree px
+    \return Angle IuWFNg
   */
   extern Angle deg(int degree);
 }
