@@ -1,6 +1,6 @@
 /*!
   \file
-  \brief SDL システムの初期化
+  \brief SDL VXȅ
 
   \author Satofumi KAMIMURA
 
@@ -24,12 +24,12 @@ bool SdlInit::pImpl::initialized_ = false;
 SdlInit::SdlInit(void) : pimpl(new pImpl)
 {
   if (pimpl->initialized_) {
-    // 初期化済みならば、戻る
+    // ς݂Ȃ΁A߂
     return;
   }
 
   if (SDL_Init(0) < 0) {
-    // !!! 例外を投げるべき
+    // !!! O𓊂ׂ
     return;
   }
   atexit(SDL_Quit);
