@@ -1,10 +1,10 @@
 /*!
   \file
-  \brief SCIP 通信処理
+  \brief SCIP ʐM
 
   \author Satofumi KAMIMURA
 
-  $Id: ScipHandler.cpp 1469 2009-10-30 00:45:14Z satofumi $
+  $Id: ScipHandler.cpp 1705 2010-02-19 10:33:05Z satofumi $
 */
 
 #include "ScipHandler.h"
@@ -28,9 +28,16 @@ using namespace std;
 
 namespace
 {
+  typedef enum {
+    ProcessContinue,
+    ProcessBreak,
+    ProcessNormal,
+  } LoopProcess;
+
   void clearReceived(vector<long>& data, CaptureType& type,
                      int& line_count, int& timeout,
-                     string& remain_string, string& left_packet_data)
+                     string& remain_string,
+                     string& left_packet_data)
   {
     data.clear();
     type = TypeUnknown;
@@ -45,16 +52,19 @@ namespace
 struct ScipHandler::pImpl
 {
   enum {
-    ContinuousTimeout = 100,
-    FirstTimeout = 1000,
+    TotalTimeout = 1000,        // [msec]
+    ContinuousTimeout = 100,    // [msec]
+    FirstTimeout = 1000,        // [msec]
 
-    BufferSize = 64 + 1 + 1,    // データ長 + チェックサム + 改行
+    BufferSize = 64 + 1 + 1,    // f[^ + `FbNT + s
 
     ResponseTimeout = -1,
     MismatchResponse = -2,
     SendFail = -3,
     ChecksumFail = -4,
     Scip11Response = -14,
+
+    InvalidRange = -1,
   };
 
   typedef enum {
@@ -88,7 +98,7 @@ struct ScipHandler::pImpl
     long try_baudrates[] = { 115200, 19200, 38400, };
     size_t try_size = sizeof(try_baudrates) / sizeof(try_baudrates[0]);
 
-    // 接続したいボーレートを配列の先頭と入れ換える
+    // ڑ{[[gz̐擪Ɠꊷ
     for (size_t i = 1; i < try_size; ++i) {
       if (baudrate == try_baudrates[i]) {
         swap(try_baudrates[0], try_baudrates[i]);
@@ -96,50 +106,50 @@ struct ScipHandler::pImpl
       }
     }
 
-    // 指定のボーレートで接続し、応答が返されるかどうか試す
+    // w̃{[[gŐڑAԂ邩ǂ
     for (size_t i = 0; i < try_size; ++i) {
 
-      // ホスト側のボーレートを変更
+      // zXg̃{[[gύX
       if (! con_->setBaudrate(try_baudrates[i])) {
         error_message_ = con_->what();
         return false;
       }
 
-      // 前回分の受信パケットを読み捨て
+      // O񕪂̎MpPbgǂݎ̂
       con_->clear();
 
-      // QT の発行
+      // QT ̔s
       int return_code = -1;
       char qt_expected_response[] = { 0, -1 };
-      // return_code を使いたいため、setLaserOutput() を用いずに QT を送信する
+      // return_code g߁AsetLaserOutput() p QT 𑗐M
       if (response(return_code, "QT\n", qt_expected_response)) {
         laser_state_ = LaserOff;
         return changeBothBaudrate(baudrate);
 
       } else if (return_code == ResponseTimeout) {
-        // ボーレートが違っていて、通信できなかったとみなす
+        // {[[gĂāAʐMłȂƂ݂Ȃ
         error_message_ = "baudrate is not detected.";
         continue;
 
       } else if (return_code == MismatchResponse) {
-        // MD/MS の応答とみなし、受信データを読み飛ばす
+        // MD/MS ̉Ƃ݂ȂAMf[^ǂݔ΂
 	con_->clear();
         skip(con_, ContinuousTimeout);
         return changeBothBaudrate(baudrate);
 
       } else if (return_code == Scip11Response) {
-        // SCIP1.1 プロトコルの場合のみ、SCIP2.0 を送信する
+        // SCIP1.1 vgȐꍇ̂݁ASCIP2.0 𑗐M
         char scip20_expected_response[] = { 0, -1 };
         if (! response(return_code, "SCIP2.0\n", scip20_expected_response)) {
           error_message_ =
-            "SCIP1.1 protocol is not supported. Please update URG firmware.";
+            "SCIP1.1 protocol is not supported. Please update URG firmware, or reconnect after a few seconds.";
           return false;
         }
         laser_state_ = LaserOff;
         return changeBothBaudrate(baudrate);
 
       } else if (return_code == 0xE) {
-        // TM モードとみなし、TM2 を発行する
+        // TM [hƂ݂ȂATM2 𔭍s
         char tm2_expected_response[] = { 0, -1 };
         if (response(return_code, "TM2\n", tm2_expected_response)) {
           laser_state_ = LaserOff;
@@ -155,40 +165,43 @@ struct ScipHandler::pImpl
 
   bool changeBothBaudrate(long baudrate)
   {
-    // 既に目標対象のボーレート値ならば、成功とみなす
-    // この関数は、ScipHandler::connect() か、それ以後でないと呼ばれないため
+    // ɖڕWΏۂ̃{[[glȂ΁AƂ݂Ȃ
+    // ̊֐́AScipHandler::connect() AȌłȂƌĂ΂Ȃ
     if (con_->baudrate() == baudrate) {
       return true;
     }
 
-    // URG 側のボーレートを変更
+    // URG ̃{[[gύX
     int pre_ticks = ticks();
     if (! changeBaudrate(baudrate)) {
       return false;
     }
 
-    // シリアル通信の場合、ボーレート変更後、１周分だけ待つ必要がある
+    // VAʐM̏ꍇA{[[gύXAP҂Kv
     int reply_msec = ticks() - pre_ticks;
     delay((reply_msec * 4 / 3) + 10);
 
-    // ホスト側のボーレートを変更
+    // zXg̃{[[gύX
     return con_->setBaudrate(baudrate);
   }
 
 
   bool changeBaudrate(long baudrate)
   {
+#if 0
+    // Tcpip ڑɑΉ邽߁ARgAEg
     if (! ((baudrate == 19200) || (baudrate == 38400) ||
            (baudrate == 57600) || (baudrate == 115200))) {
       error_message_ = "Invalid baudrate value.";
       return false;
     }
+#endif
 
-    // SS を送信し、URG 側のボーレートを変更する
+    // SS 𑗐MAURG ̃{[[gύX
     char send_buffer[] = "SSxxxxxx\n";
     snprintf(send_buffer, 10, "SS%06ld\n", baudrate);
     int return_code = -1;
-    // !!! 既に設定対象のボーレート、の場合の戻り値を ss_expected... に追加する
+    // !!! ɐݒΏۂ̃{[[gȀꍇ̖߂l ss_expected... ɒǉ
     char ss_expected_response[] = { 0, 0x3, 0x4, -1 };
     if (! response(return_code, send_buffer, ss_expected_response)) {
       error_message_ = "Baudrate change fail.";
@@ -201,7 +214,7 @@ struct ScipHandler::pImpl
 
   bool loadParameter(RangeSensorParameter& parameters)
   {
-    // PP の送信とデータの受信
+    // PP ̑Mƃf[^̎M
     int return_code = -1;
     char pp_expected_response[] = { 0, -1 };
     vector<string> lines;
@@ -210,17 +223,17 @@ struct ScipHandler::pImpl
       return false;
     }
 
-    // PP 応答内容の格納
+    // PP e̊i[
     if (lines.size() != 8) {
       error_message_ = "Invalid PP response.";
       return false;
     }
 
-    // !!! チェックサムの評価を行うべき
+    // !!! `FbNT̕]sׂ
 
     int modl_length =
       static_cast<int>(lines[RangeSensorParameter::MODL].size());
-    // 最初のタグと、チェックサムを除いた文字列を返す
+    // ŏ̃^OƁA`FbNTԂ
     if (modl_length > (5 + 2)) {
       modl_length -= (5 + 2);
     }
@@ -264,7 +277,7 @@ struct ScipHandler::pImpl
       return false;
     }
 
-    // エコーバックの受信
+    // GR[obN̎M
     char buffer[BufferSize];
     int recv_size = readline(con_, buffer, BufferSize, FirstTimeout);
     if (recv_size < 0) {
@@ -273,7 +286,7 @@ struct ScipHandler::pImpl
       return false;
     }
 
-    // シリアル接続でボーレート変更直後の 0x00 は、判定外とする
+    // VAڑŃ{[[gύX 0x00 ́AOƂ
     if (! ((recv_size == 1) && (buffer[0] == 0x00))) {
       if ((recv_size != static_cast<int>(send_size - 1)) ||
           (strncmp(buffer, send_command, recv_size))) {
@@ -283,19 +296,19 @@ struct ScipHandler::pImpl
       }
     }
 
-    // 応答の受信
-    // !!! 上記の処理となるべく共通にする
-    // !!! SCIP1.1 プロトコルの応答は、負号を付加した上で return_code に格納する
+    // ̎M
+    // !!! L̏ƂȂׂʂɂ
+    // !!! SCIP1.1 vgR̉́At return_code Ɋi[
     recv_size = readline(con_, buffer, BufferSize, ContinuousTimeout);
     if (recv_size < 0) {
-      // !!! この処理をくくる
+      // !!! ̏
       error_message_ = "response timeout.";
       return_code = ResponseTimeout;
       return false;
     }
     if (recv_size == 3) {
-      // ３文字ならば、SCIP2.0 とみなしてチェックサムを確認する
-      // !!! チェックサムの確認
+      // RȂ΁ASCIP2.0 Ƃ݂Ȃă`FbNTmF
+      // !!! `FbNT̊mF
       if (! checkSum(buffer, recv_size - 1, buffer[recv_size - 1])) {
 	return_code = ChecksumFail;
 	return false;
@@ -304,13 +317,13 @@ struct ScipHandler::pImpl
       return_code = strtol(buffer, NULL, 16);
 
     } else if (recv_size == 1) {
-      // １文字ならば、SCIP1.1 とみなして 16進変換した値に負号をつけて返す
+      // PȂ΁ASCIP1.1 Ƃ݂Ȃ 16iϊlɕĕԂ
       buffer[1] = '\0';
       return_code = -strtol(buffer, NULL, 16);
     }
 
-    // データ領域の受信
-    // １行読み出し、改行のみならば終了とみなす
+    // f[^̈̎M
+    // PsǂݏoAŝ݂ȂΏIƂ݂Ȃ
     do {
       recv_size = readline(con_, buffer, BufferSize, ContinuousTimeout);
       if (lines && (recv_size > 0)) {
@@ -332,8 +345,8 @@ struct ScipHandler::pImpl
     if (((on == true) && (laser_state_ == LaserOn)) ||
         ((on == false) && (laser_state_ == LaserOff))) {
       if (! force) {
-        // レーザ出力が現在の状態と同じならば戻る
-        // 強制設定フラグが true のときは戻らずに設定を行う
+        // [Uo݂͂̏ԂƓȂΖ߂
+        // ݒtO true ̂Ƃ͖߂炸ɐݒs
         return true;
       }
     }
@@ -354,7 +367,7 @@ struct ScipHandler::pImpl
     } else {
       // "QT"
       if (! mx_capturing_) {
-        // 消灯するための QT では、応答を待つべき
+        // 邽߂ QT ł́A҂ׂ
         int return_code = -1;
         char qt_expected_response[] = { 0, -1 };
         if (! response(return_code, "QT\n", qt_expected_response)) {
@@ -365,8 +378,8 @@ struct ScipHandler::pImpl
         return true;
 
       } else {
-        // MD を中断するための QT では、応答を待ってはならない
-        // 応答は、受信スレッド内で処理される
+        // MD 𒆒f邽߂ QT ł́A҂Ă͂ȂȂ
+        // ́AMXbhŏ
         con_->send("QT\n", 3);
         isPreCommand_QT_ = true;
       }
@@ -376,6 +389,105 @@ struct ScipHandler::pImpl
   }
 
 
+  bool testChecksum(const char* buffer, int line_size,
+                    vector<long>& data, CaptureType& type,
+                    int line_count, int timeout,
+                    string& remain_string, string& left_packet_data)
+  {
+    if (! checkSum(buffer, line_size - 1, buffer[line_size - 1])) {
+      log_printf("checksum error: %s\n", buffer);
+      // return InvalidData;
+      // !!! URG ̃pPbgG[ȂȂA̎ɖ߂
+
+      // !!! ݂邾̃pPbgǂݔ΂
+      error_message_ = "invalid packet.";
+      clearReceived(data, type, line_count, timeout,
+                    remain_string, left_packet_data);
+      return false;
+    }
+
+    return true;
+  }
+
+
+  LoopProcess handleEchoback(const char* buffer, CaptureSettings& settings,
+                             CaptureType& type, vector<long>& data,
+                             int line_count, int timeout,
+                             string& remain_string,
+                             string& left_packet_data)
+  {
+    string line = buffer;
+    if ((! line.compare(0, 2, "GD")) || (! line.compare(0, 2, "GS"))) {
+      if (! parseGdEchoback(settings, line)) {
+        return ProcessBreak;
+      }
+      type = (line[1] = 'D') ? GD : GS;
+
+    } else if ((! line.compare(0, 2, "MD")) ||
+               (! line.compare(0, 2, "MS"))) {
+      if (! parseMdEchoback(settings, line)) {
+        return ProcessBreak;
+      }
+      type = (line[1] = 'D') ? MD : MS;
+      laser_state_ = LaserOn;
+
+    } else if (! line.compare(0, 2, "ME")) {
+      if (! parseMeEchoback(settings, line)) {
+        return ProcessBreak;
+      }
+      type = ME;
+      laser_state_ = LaserOn;
+
+    } else if (! line.compare(0, 2, "QT")) {
+      settings.remain_times = 0;
+      laser_state_ = LaserOff;
+      mx_capturing_ = false;
+      return ProcessNormal;
+
+    } else {
+      //return InvalidData;
+      // !!! URG ȃpPbgԂ悤ɂȂA̎ɖ߂
+
+      clearReceived(data, type, line_count, timeout,
+                    remain_string, left_packet_data);
+      //fprintf(stderr, "invalid data: %s\n", buffer);
+      return ProcessContinue;
+    }
+
+    data.reserve(settings.capture_last + 1);
+    return ProcessNormal;
+  }
+
+
+  void handleReturnCode(char* buffer, CaptureSettings& settings, int timeout,
+                        CaptureType& type, int* total_times)
+  {
+    // !!!  2 + 1 ̃`FbNׂ
+    buffer[2] = '\0';
+    settings.error_code = atoi(buffer);
+
+    if (settings.error_code == 10) {
+      // [Uo
+      laser_state_ = pImpl::LaserOff;
+    }
+
+    // "0B" ԂꂽꍇAZTƃzXg̉Ă\̂
+    // ǂݎ̂Ă
+    if (! strncmp(buffer, "0B", 2)) {
+      skip(con_, TotalTimeout, timeout);
+    }
+
+    // !!! "00P" Ƃ̔rׂ
+    if ((settings.error_code == 0) &&
+        ((type == MD) || (type == MS) || (type == ME))) {
+      if (total_times) {
+        *total_times = settings.remain_times;
+      }
+      type = Mx_Reply;
+    }
+  }
+
+
   CaptureType receiveCaptureData(vector<long>& data,
                                  CaptureSettings& settings, long* timestamp,
                                  int* remain_times, int* total_times)
@@ -390,121 +502,65 @@ struct ScipHandler::pImpl
 
     error_message_ = "no response.";
 
-    // !!! 以下の処理が長い。関数化すべき
     CaptureType type = TypeUnknown;
     int timeout = FirstTimeout;
     int line_size = 0;
     while ((line_size = readline(con_, buffer, BufferSize, timeout)) > 0) {
       //fprintf(stderr, "%d: % 3d: %s\n", ticks(), line_count, buffer);
 
-      // チェックサムの確認
+      // `FbNT̊mF
       if (line_count != 0) {
-        // エコーバックにはチェックサム文字列がないので、無視
-        if (! checkSum(buffer, line_size - 1, buffer[line_size - 1])) {
-          log_printf("checksum error: %s\n", buffer);
-          // return InvalidData;
-          // !!! URG のパケットエラーがなくなったら、この実装に戻す
-
-          // !!! 存在するだけのパケットを読み飛ばす
-          error_message_ = "invalid packet.";
-          clearReceived(data, type, line_count, timeout,
-                        remain_string, left_packet_data);
+        // GR[obNɂ̓`FbNT񂪂Ȃ̂ŁA
+        if (! testChecksum(buffer, line_size, data, type, line_count, timeout,
+                           remain_string, left_packet_data)) {
           continue;
         }
       }
 
       if (line_count == 0) {
-
-        // エコーバック
-        string line = buffer;
-        if ((! line.compare(0, 2, "GD")) || (! line.compare(0, 2, "GS"))) {
-          if (! parseGdEchoback(settings, line)) {
-            break;
-          }
-          type = (line[1] = 'D') ? GD : GS;
-          data.reserve(settings.capture_last + 1);
-
-        } else if ((! line.compare(0, 2, "MD")) ||
-                   (! line.compare(0, 2, "MS"))) {
-          if (! parseMdEchoback(settings, line)) {
-            break;
-          }
-          type = (line[1] = 'D') ? MD : MS;
-          laser_state_ = LaserOn;
-          data.reserve(settings.capture_last + 1);
-
-        } else if (! line.compare(0, 2, "ME")) {
-          if (! parseMeEchoback(settings, line)) {
-            break;
-          }
-          type = ME;
-          laser_state_ = LaserOn;
-          data.reserve(settings.capture_last + 1);
-
-        } else if (! line.compare(0, 2, "QT")) {
-          settings.remain_times = 0;
-          laser_state_ = LaserOff;
-          mx_capturing_ = false;
-
-        } else {
-          //return InvalidData;
-          // !!! URG が正常なパケットを返すようになったら、この実装に戻す
-
-          clearReceived(data, type, line_count, timeout,
-                        remain_string, left_packet_data);
-          //fprintf(stderr, "invalid data: %s\n", buffer);
+        // GR[obN
+        LoopProcess loop_process =
+          handleEchoback(buffer, settings, type, data, line_count, timeout,
+                         remain_string, left_packet_data);
+        if (loop_process == ProcessContinue) {
           continue;
+
+        } else if (loop_process == ProcessBreak) {
+          break;
         }
 
       } else if (line_count == 1) {
-        // 応答コード
-        // !!! 長さが 2 + 1 かのチェックをすべき
-        buffer[2] = '\0';
-        settings.error_code = atoi(buffer);
-
-        if (settings.error_code == 10) {
-          // レーザ消灯を検出
-          laser_state_ = pImpl::LaserOff;
-        }
-
-        // !!! "00P" との比較をすべき
-        if ((settings.error_code == 0) &&
-            ((type == MD) || (type == MS) || (type == ME))) {
-          if (total_times) {
-            *total_times = settings.remain_times;
-          }
-          type = Mx_Reply;
-        }
+        // R[h
+        handleReturnCode(buffer, settings, timeout, type, total_times);
 
       } else if (line_count == 2) {
-        // タイムスタンプ
+        // ^CX^v
         if (timestamp) {
           *timestamp = decode(buffer, 4);
         }
       } else {
         if (line_count == 3) {
-          // 受信データがない先頭からの領域を、ダミーデータで埋める
+          // Mf[^Ȃ擪̗̈A_~[f[^Ŗ߂
           for (int i = 0; i < settings.capture_first; ++i) {
-            data.push_back(0);
+            data.push_back(InvalidRange);
             if (type == ME) {
-              // ME 受信のときは、強度データ分も埋める
-              data.push_back(0);
+              // ME M̂Ƃ́Axf[^߂
+              data.push_back(InvalidRange);
             }
           }
         }
-        // 距離データ
+        // f[^̊i[
         left_packet_data =
-          addLengthData(data, string(buffer),
-                        left_packet_data, settings.data_byte,
-                        settings.skip_lines);
+          addLengthData(data, string(buffer), left_packet_data,
+                        settings.data_byte, settings.skip_lines);
       }
       ++line_count;
       timeout = ContinuousTimeout;
     }
 
-    // !!! type が距離データ取得のときは、正常に受信が完了したか、を確認すべき
+    // !!! type f[^擾̂Ƃ́AɎMAmFׂ
 
-    // ME で "まとめる数" 設定以上のデータが返されるバグに対処
+    // ME  "܂Ƃ߂鐔" ݒȏ̃f[^ԂoOɑΏ
     size_t expected_n = settings.capture_last * ((type == ME) ? 2 : 1);
     if (expected_n < data.size()) {
       data.erase(data.begin() + expected_n, data.end());
@@ -525,7 +581,7 @@ struct ScipHandler::pImpl
     }
 
     settings.capture_first = substr2int(line, 2, 4);
-    settings.capture_last = substr2int(line, 6, 4);
+    settings.capture_last = substr2int(line, 6, 4) + 1;
     int skip_lines = substr2int(line, 10, 2);
     settings.skip_lines = (skip_lines == 0) ? 1 : skip_lines;
     settings.data_byte = (line[1] == 'D') ? 3 : 2;
@@ -542,7 +598,7 @@ struct ScipHandler::pImpl
     }
 
     settings.capture_first = substr2int(line, 2, 4);
-    settings.capture_last = substr2int(line, 6, 4);
+    settings.capture_last = substr2int(line, 6, 4) + 1;
     int skip_lines = substr2int(line, 10, 2);
     settings.skip_lines = (skip_lines == 0) ? 1 : skip_lines;
     settings.skip_frames = substr2int(line, 12, 1);
@@ -550,9 +606,9 @@ struct ScipHandler::pImpl
     settings.data_byte = (line[1] == 'D') ? 3 : 2;
 
     if (settings.remain_times == 1) {
-      // 最後のデータ取得で、レーザを消灯扱いにする
-      // 本当は、次のデータ取得後にレーザは消灯されている
-      // 1 で判定すると、取得回数が 1 のときにも正常に動作するため
+      // Ō̃f[^擾ŁA[Uɂ
+      // {́Ãf[^擾Ƀ[U͏Ă
+      // 1 Ŕ肷ƁA擾񐔂 1 ̂Ƃɂɓ삷邽
       mx_capturing_ = false;
 
     } else {
@@ -575,7 +631,7 @@ struct ScipHandler::pImpl
     }
 
     settings.capture_first = substr2int(line, 2, 4);
-    settings.capture_last = substr2int(line, 6, 4);
+    settings.capture_last = substr2int(line, 6, 4) + 1;
     int skip_lines = substr2int(line, 10, 2);
     settings.skip_lines = (skip_lines == 0) ? 1 : skip_lines;
     settings.skip_frames = substr2int(line, 12, 1);
@@ -599,11 +655,11 @@ struct ScipHandler::pImpl
                        const size_t data_byte, const int skip_lines = 1)
   {
     if (line.empty()) {
-      // 空行の場合、戻る
+      // s̏ꍇA߂
       return left_packet_data;
     }
 
-    // 端数。次回に処理する分
+    // [Bɏ镪
     string left_byte = left_packet_data;
 
     size_t data_size = (left_byte.size() + (line.size() - 1)) / data_byte;
@@ -611,7 +667,7 @@ struct ScipHandler::pImpl
     for (size_t i = 0; i < n; ++i) {
       left_byte.push_back(line[i]);
       if (left_byte.size() >= data_byte) {
-        // データを距離に変換して、格納
+        // f[^ɕϊāAi[
         long length = decode(&left_byte[0], data_byte);
         for (int j = 0; j < skip_lines; ++j) {
           data.push_back(length);
@@ -693,8 +749,8 @@ bool ScipHandler::connect(const char* device, long baudrate)
 int ScipHandler::send(const char data[], int size)
 {
   if (size >= 2) {
-    // コマンド送信後の受信前だと、レーザ点灯中の判定ができないため、
-    // ここでレーザ点灯中の状態を判定する
+    // R}hM̎MOƁA[U_̔肪łȂ߁A
+    // Ń[U_̏Ԃ𔻒肷
     if ((! strncmp("MD", data, 2)) || (! strncmp("MS", data, 2)) ||
         (! strncmp("ME", data, 2))) {
       pimpl->laser_state_ = pImpl::LaserOn;
@@ -734,7 +790,7 @@ bool ScipHandler::setRawTimestampMode(bool on)
   char send_command[] = "TMx\n";
   send_command[2] = (on) ? '0' : '2';
 
-  // TM0 or TM2 の送信
+  // TM0 or TM2 ̑M
   int return_code = -1;
   char expected_response[] = { 0, -1 };
   if (! pimpl->response(return_code, send_command, expected_response)) {
@@ -742,7 +798,7 @@ bool ScipHandler::setRawTimestampMode(bool on)
     return false;
   }
 
-  // TM1, TM2 の応答が正常ならば、レーザは消灯しているはず
+  // TM1, TM2 ̉Ȃ΁A[U͏Ă͂
   pimpl->laser_state_ = pImpl::LaserOff;
 
   return true;
@@ -751,7 +807,7 @@ bool ScipHandler::setRawTimestampMode(bool on)
 
 bool ScipHandler::rawTimestamp(int* timestamp)
 {
-  // TM1 の値を返す
+  // TM1 ̒lԂ
   int return_code = -1;
   char expected_response[] = { 0, -1 };
   vector<string> lines;
