@@ -1,12 +1,12 @@
 /*!
   \file
-  \brief URG センサ制御
+  \brief URG ZT
 
   \author Satofumi KAMIMURA
 
-  $Id: UrgCtrl.cpp 1469 2009-10-30 00:45:14Z satofumi $
+  $Id: UrgCtrl.cpp 1669 2010-02-04 08:28:27Z satofumi $
 
-  \todo remain_times の 100 をマクロで置き換える
+  \todo remain_times  100 }NŒu
 */
 
 #include "UrgCtrl.h"
@@ -30,6 +30,14 @@ using namespace qrk;
 using namespace std;
 
 
+namespace
+{
+  enum {
+    MdScansMax = 100,           // [times]
+  };
+}
+
+
 struct UrgCtrl::pImpl
 {
   struct ScanData
@@ -76,8 +84,8 @@ struct UrgCtrl::pImpl
 
     string createCaptureCommand(void)
     {
-      // !!! parameter 受信直後に、送受信パラメータへの代入を行う
-      // !!! ここでの送受信には、送受信パラメータの内容を用いる
+      // !!! parameter MɁAMp[^ւ̑s
+      // !!! ł̑Mɂ́AMp[^̓ep
 
       char buffer[] = "GDbbbbeeeegg\n";
       snprintf(buffer, strlen(buffer) + 1, "GD%04d%04d%02u\n",
@@ -92,10 +100,10 @@ struct UrgCtrl::pImpl
     {
       pimpl_->retry_times_ = 0;
 
-      // レーザを点灯させておく
+      // [U_Ă
       pimpl_->scip_.setLaserOutput(ScipHandler::On);
 
-      // データ取得コマンドの送信
+      // f[^擾R}h̑M
       string command = createCaptureCommand();
       int n = pimpl_->scip_.send(command.c_str(),
                                  static_cast<int>(command.size()));
@@ -114,7 +122,7 @@ struct UrgCtrl::pImpl
     {
       static_cast<void>(size);
 
-      // 何もしない
+      // Ȃ
     }
 
 
@@ -169,13 +177,13 @@ struct UrgCtrl::pImpl
         return -1;
       }
 
-      // スレッドを起動
+      // XbhN
       LockGuard guard(pimpl_->mutex_);
       if ((! pimpl_->thread_.isRunning()) && pimpl_->data_buffer_.empty()) {
         pimpl_->thread_.run(1);
       }
 
-      // 取得済みデータがなければ、戻る
+      // 擾ς݃f[^Ȃ΁A߂
       if (pimpl_->data_buffer_.empty()) {
         if (pimpl_->invalid_packet_) {
           return -1;
@@ -239,14 +247,14 @@ struct UrgCtrl::pImpl
       char buffer[] = "MEbbbbeeeeggstt\n";
       if ((! pimpl_->urg_type_.compare("URG-04LX")) ||
           (! pimpl_->urg_type_.compare("URG-04LX-UG01"))) {
-        // URG-04LX ならば、FF 形式でデータ送信を行う
+        // URG-04LX Ȃ΁AFF `Ńf[^Ms
         snprintf(buffer, strlen(buffer) + 1, "MD%04d%04dFF%01u%02u\n",
                  pimpl_->capture_begin_, pimpl_->capture_end_,
                  pimpl_->capture_frame_interval_,
                  (pimpl_->capture_times_ > 99) ? 0 : pimpl_->capture_times_);
 
       } else {
-        // UTM-30LX ならば、ME コマンドを用いる
+        // UTM-30LX Ȃ΁AME R}hp
         snprintf(buffer, strlen(buffer) + 1, "ME%04d%04d%02u%01u%02u\n",
                  pimpl_->capture_begin_, pimpl_->capture_end_,
                  pimpl_->capture_skip_lines_,
@@ -266,12 +274,12 @@ struct UrgCtrl::pImpl
       }
 
       LockGuard guard(pimpl_->mutex_);
-      // 取得済みデータがなければ、スレッドを起動
+      // 擾ς݃f[^Ȃ΁AXbhN
       if ((! pimpl_->thread_.isRunning()) && pimpl_->data_buffer_.empty()) {
         pimpl_->thread_.run(1);
       }
 
-      // 取得済みデータがなければ、戻る
+      // 擾ς݃f[^Ȃ΁A߂
       if (pimpl_->data_buffer_.empty()) {
         if (pimpl_->invalid_packet_) {
           return -1;
@@ -290,7 +298,7 @@ struct UrgCtrl::pImpl
 
       if ((pimpl_->urg_type_.compare("URG-04LX")) &&
           (pimpl_->urg_type_.compare("URG-04LX-UG01"))) {
-        // UTM-30LX のとき
+        // UTM-30LX ̂Ƃ
         int skip_lines = settings.skip_lines;
         int min_length = pimpl_->parameters_.distance_min;
         int n = data.size() / skip_lines / 2;
@@ -312,7 +320,7 @@ struct UrgCtrl::pImpl
 
       } else if ((! pimpl_->urg_type_.compare("URG-04LX")) ||
                  (! pimpl_->urg_type_.compare("URG-04LX-UG01"))) {
-        // URG-04LX のとき
+        // URG-04LX ̂Ƃ
         size_t n = data.size();
         int min_length = pimpl_->parameters_.distance_min;
         pimpl_->intensity_data_.length_data.reserve(data.size());
@@ -328,7 +336,7 @@ struct UrgCtrl::pImpl
           }
         }
       } else {
-        // !!! エラー処理
+        // !!! G[
       }
 
       return static_cast<int>(data.size());
@@ -361,7 +369,7 @@ struct UrgCtrl::pImpl
   string error_message_;
   UrgCtrl* parent_;
   Connection* con_;
-  SerialDevice* serial_; //!< 有効な接続オブジェクトがないときに用いる
+  SerialDevice* serial_; //!< LȐڑIuWFNgȂƂɗp
   ScipHandler scip_;
   RangeSensorParameter parameters_;
   string urg_type_;
@@ -417,8 +425,8 @@ struct UrgCtrl::pImpl
   {
     disconnect();
 
-    // con_ は外部からセットされる可能性があるため、このクラスでは解放しない
-    // serial_ のみ解放する
+    // con_ ͊OZbg\邽߁ÃNXł͉Ȃ
+    // serial_ ̂݉
     delete serial_;
   }
 
@@ -440,7 +448,7 @@ struct UrgCtrl::pImpl
     }
     scip_.setConnection(con_);
 
-    // ボーレートを検出した上でのデバイスとの接続
+    // {[[goł̃foCXƂ̐ڑ
     if (! scip_.connect(device, baudrate)) {
       error_message_ = scip_.what();
       return false;
@@ -457,7 +465,7 @@ struct UrgCtrl::pImpl
 
   bool loadParameter(void)
   {
-    // URG パラメータの取得
+    // URG p[^̎擾
     RangeSensorParameter parameters;
     if (! scip_.loadParameter(parameters)) {
       error_message_ = scip_.what();
@@ -468,8 +476,8 @@ struct UrgCtrl::pImpl
     size_t type_length = parameters_.model.find('(');
     urg_type_ = parameters_.model.substr(0, type_length);
 
-    // !!! capture_begin_, capture_end_ との調整をすべき
-    // !!! min(), max() を使うこと
+    // !!! capture_begin_, capture_end_ Ƃׂ̒
+    // !!! min(), max() g
 
     return true;
   }
@@ -491,15 +499,15 @@ struct UrgCtrl::pImpl
   }
 
 
-  // AutoCapture, IntensityCapture のデータ取得を行う
+  // AutoCapture, IntensityCapture ̃f[^擾s
   static int capture_thread(void* args)
   {
     pImpl* obj = static_cast<pImpl*>(args);
 
-    // 設定に基づいて、データ受信コマンドを作成して発行
+    // ݒɊÂāAf[^MR}h쐬Ĕs
     string capture_command = obj->capture_->createCaptureCommand();
     if (capture_command.empty()) {
-      // ここのエラーが IntensityCapture のときのみ発生するのに依存した実装
+      // ̃G[ IntensityCapture ̂Ƃ̂ݔ̂Ɉˑ
       obj->error_message_ = "This urg is not support intensity capture.";
       return -1;
     }
@@ -511,32 +519,32 @@ struct UrgCtrl::pImpl
       return -1;
     }
 
-    // 受信待ち
+    // M҂
     ScanData data;
-    int remain_times = 100;
+    int remain_times = MdScansMax;
     int total_times = 0;
     while (1) {
-      // 受信完了、およびエラーで抜ける
+      // MAуG[Ŕ
       obj->invalid_packet_ = false;
       CaptureType type =
         obj->scip_.receiveCaptureData(data.length_data, data.settings,
                                       &data.timestamp,
                                       &remain_times, &total_times);
       if (type == Mx_Reply) {
-        // MS/MD の応答パケットの場合、次のデータを待つ
+        // MS/MD ̉pPbg̏ꍇÃf[^҂
         continue;
       }
 
       if (! ((type == MD) || (type == MS) || (type == ME))) {
-        // 受信データでなければ、スレッド処理を中断する
+        // Mf[^łȂ΁AXbh𒆒f
         obj->invalid_packet_ = true;
         ++obj->retry_times_;
         break;
       }
       obj->retry_times_ = 0;
 
-      // タイムスタンプが 24 bit しかないため、１巡することへの対処
-      if (data.timestamp < obj->pre_timestamp_) {
+      // ^CX^v 24 bit Ȃ߁AP邱Ƃւ̑Ώ
+      if ((data.timestamp >= 0) && (data.timestamp < obj->pre_timestamp_)) {
         obj->base_timestamp_ += 1 << 24;
       }
       obj->pre_timestamp_ = data.timestamp;
@@ -545,7 +553,7 @@ struct UrgCtrl::pImpl
       LockGuard guard(obj->mutex_);
       deque<ScanData>& data_buffer = obj->data_buffer_;
 
-      // 古くなったデータを取り除く
+      // ÂȂf[^菜
       int current_size = static_cast<int>(data_buffer.size());
       int erase_size =
         current_size - static_cast<int>(obj->capture_->capturesSize());
@@ -554,12 +562,12 @@ struct UrgCtrl::pImpl
                           data_buffer.begin() + erase_size);
       }
 
-      // 今回のデータを追加
+      // ̃f[^ǉ
       ScanData dummy_data;
       data_buffer.push_back(dummy_data);
       swap(data_buffer.back(), data);
 
-      if ((obj->capture_times_ > 0) && (remain_times < 100)) {
+      if ((obj->capture_times_ > 0) && (remain_times < MdScansMax)) {
         obj->remain_times_ = remain_times;
       } else {
         --obj->remain_times_;
@@ -570,7 +578,7 @@ struct UrgCtrl::pImpl
       obj->parent_->captureReceived();
 
       if ((total_times > 0) && (remain_times == 0)) {
-        // 取得が終了したら、抜ける
+        // 擾IA
         break;
       }
     }
@@ -632,13 +640,13 @@ struct UrgCtrl::pImpl
 
   bool setTimestamp(int timestamp, int* response_msec, int* force_delay_msec)
   {
-    // TM0 モードに遷移
-    // !!! true, false をキーワードで置換すること
+    // TM0 [hɑJ
+    // !!! true, false L[[hŒu邱
     if (! scip_.setRawTimestampMode(true)) {
       return false;
     }
 
-    // TM1 のタイムスタンプを取得し、通信遅延と URG のタイムスタンプを取得する
+    // TM1 ̃^CX^v擾AʐMx URG ̃^CX^v擾
     int urg_timestamp = 0;
     int first_ticks = ticks();
     if (scip_.rawTimestamp(&urg_timestamp)) {
@@ -652,7 +660,7 @@ struct UrgCtrl::pImpl
       timestamp_offset_ =  urg_timestamp - timestamp + delay;
     }
 
-    // URG タイムスタンプ用のオフセット時間を計算し、TM2 で抜ける
+    // URG ^CX^vp̃ItZbgԂvZATM2 Ŕ
     if (! scip_.setRawTimestampMode(false)) {
       return false;
     }
@@ -693,10 +701,10 @@ struct UrgCtrl::pImpl
       return;
     }
 
-    // QT コマンドの発行
+    // QT R}h̔s
     scip_.setLaserOutput(ScipHandler::Off);
 
-    // 応答を待つ
+    // ҂
     if (thread_.isRunning()) {
       thread_.wait();
     }
@@ -724,7 +732,7 @@ UrgCtrl::~UrgCtrl(void)
 
 void UrgCtrl::captureReceived(void)
 {
-  // 受信完了を継承先のクラスが利用するためのメソッド
+  // Mp̃NXp邽߂̃\bh
 }
 
 
@@ -780,7 +788,7 @@ long UrgCtrl::maxDistance(void) const
 
 int UrgCtrl::maxScanLines(void) const
 {
-  // +1 は、parameters_ が未初期化のときに new long [0] しないための処置
+  // +1 ́Aparameters_ ̂Ƃ new long [0] Ȃ߂̏u
   return pimpl->parameters_.area_max + 1;
 }
 
@@ -812,7 +820,7 @@ int UrgCtrl::scanMsec(void) const
 
 void UrgCtrl::setCaptureMode(RangeCaptureMode mode)
 {
-  // capture を停止する。capture の再開は行わない
+  // capture ~Bcapture ̍ĊJ͍sȂ
   stop();
   pimpl->clear();
 
@@ -838,9 +846,9 @@ RangeCaptureMode UrgCtrl::captureMode(void)
 
 void UrgCtrl::setCaptureRange(int begin_index, int end_index)
 {
-  // !!! 排他制御
+  // !!! r
 
-  // capture を停止する。capture の再開は行わない
+  // capture ~Bcapture ̍ĊJ͍sȂ
   stop();
   pimpl->clear();
 
@@ -851,9 +859,9 @@ void UrgCtrl::setCaptureRange(int begin_index, int end_index)
 
 void UrgCtrl::setCaptureFrameInterval(size_t interval)
 {
-  // !!! 排他制御
+  // !!! r
 
-  // capture を停止する。capture の再開は行わない
+  // capture ~Bcapture ̍ĊJ͍sȂ
   stop();
   pimpl->clear();
 
@@ -863,13 +871,13 @@ void UrgCtrl::setCaptureFrameInterval(size_t interval)
 
 void UrgCtrl::setCaptureTimes(size_t times)
 {
-  // !!! 排他制御
+  // !!! r
 
-  // capture を停止する。capture の再開は行わない
+  // capture ~Bcapture ̍ĊJ͍sȂ
   stop();
   pimpl->clear();
 
-  // !!! 範囲制限の判定処理
+  // !!! ͈͐̔菈
   pimpl->capture_times_ = times;
 }
 
@@ -877,7 +885,7 @@ void UrgCtrl::setCaptureTimes(size_t times)
 
 void UrgCtrl::setCaptureSkipLines(size_t skip_lines)
 {
-  // capture を停止する。capture の再開は行わない
+  // capture ~Bcapture ̍ĊJ͍sȂ
   stop();
   pimpl->clear();
 
@@ -887,21 +895,19 @@ void UrgCtrl::setCaptureSkipLines(size_t skip_lines)
 
 int UrgCtrl::capture(vector<long>& data, long* timestamp)
 {
-  // !!! 未接続ならば、戻す
+  // !!! ڑȂ΁A߂
 
   return pimpl->capture(data, timestamp);
 }
 
 
-#if defined(USE_INTENSITY)
 int UrgCtrl::captureWithIntensity(vector<long>& data,
                                   vector<long>& intensity_data,
                                   long* timestamp)
 {
-  // !!! 未接続ならば、戻す
+  // !!! ڑȂ΁A߂
   return pimpl->captureWithIntensity(data, intensity_data, timestamp);
 }
-#endif
 
 
 void UrgCtrl::stop(void)
@@ -912,7 +918,7 @@ void UrgCtrl::stop(void)
 
 bool UrgCtrl::setTimestamp(int ticks, int* response_msec, int* force_delay_msec)
 {
-  // !!! 未接続ならば、戻す
+  // !!! ڑȂ΁A߂
 
   return pimpl->setTimestamp(ticks, response_msec, force_delay_msec);
 }
@@ -926,7 +932,7 @@ long UrgCtrl::recentTimestamp(void) const
 
 bool UrgCtrl::setLaserOutput(bool on)
 {
-  // !!! 未接続ならば、戻す
+  // !!! ڑȂ΁A߂
 
   return pimpl->scip_.setLaserOutput(on, ScipHandler::Force);
 }
@@ -974,15 +980,17 @@ bool UrgCtrl::versionLines(vector<string>& lines)
 }
 
 
-bool UrgCtrl::reset(void)
+bool UrgCtrl::reboot(void)
 {
   UrgCtrl::setLaserOutput(Off);
 
-  // RB を２回送信する
+  // send "RB" twice.
   for (int i = 0; i < 2; ++i) {
     pimpl->scip_.send("RB\n", 3);
 
-    enum { RB_Timeout = 1000 };
+    enum {
+      RB_Timeout = 1000,        // [msec]
+    };
     char recv_buffer[3];
     int send_n = pimpl->scip_.recv(recv_buffer, 3, RB_Timeout);
     if (send_n != 3) {
@@ -993,8 +1001,13 @@ bool UrgCtrl::reset(void)
     }
   }
 
-  // リセット後、直ちに切断する
   UrgCtrl::disconnect();
 
   return true;
 }
+
+
+bool UrgCtrl::reset(void)
+{
+  return reboot();
+}
